"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFeishuSheetData = void 0;
const axios_1 = __importDefault(require("axios"));
const utils_1 = require("./utils");
const defaultOptions = {
    sheetId: "",
    worksheets: [],
    accessToken: "",
    maxColumn: 100,
};
const http = axios_1.default.create({
    baseURL: "https://open.feishu.cn/open-apis/sheet/v2/spreadsheets",
    headers: {
        "Content-Type": "application/json",
    },
});
const getFeishuSheetData = (options) => __awaiter(void 0, void 0, void 0, function* () {
    const opts = Object.assign({}, defaultOptions, options);
    const columnsArray = (0, utils_1.getColumns)(opts.maxColumn);
    const requestHeaders = {
        Authorization: "Bearer " + opts.accessToken,
    };
    // 表格元数据
    const { data: metaInfo } = yield http.get(`/${opts.sheetId}/metainfo`, {
        headers: requestHeaders,
    });
    if (metaInfo.code !== 0) {
        throw new Error(metaInfo.msg);
    }
    const metaInfoData = metaInfo.data;
    //  获取表格tab页面
    const ranges = {};
    opts.worksheets.forEach((title) => {
        const sheets = metaInfoData.sheets.filter((item) => item.title === title);
        if (sheets.length) {
            const item = sheets[0];
            // 截取最大的列
            let columnEndIndex = item.columnCount - 1;
            if (columnEndIndex > opts.maxColumn - 1) {
                columnEndIndex = opts.maxColumn - 1;
            }
            ranges[`${item.sheetId}!A1:${columnsArray[columnEndIndex]}${item.rowCount}`] = item.title;
        }
    });
    const { data: sheetData } = yield http.get(`/${opts.sheetId}/values_batch_get`, {
        params: {
            ranges: Object.keys(ranges).join(","),
            valueInputOption: "ToString",
        },
        headers: requestHeaders,
    });
    return sheetData.data.valueRanges.map((values) => {
        values.title = ranges[values.range];
        return values;
    });
});
exports.getFeishuSheetData = getFeishuSheetData;
